import Joi from "joi";
import {Collection} from "../core/database.js";
import {Application,cors, jsonrequest} from "../core/http.js";
import moment from "moment";

Application.post("/collection/:catalog/add", jsonrequest(), cors(), AddCollection);

/**
 * @param {import("express").Request} request 
 * @param {import("express").Response} response 
 */
async function AddCollection(request, response)
{
    let catalog = request.params.catalog;
    let expression = Joi.object({
        data: Joi.object().required().max(873741824),
        domain: Joi.string().max(200).min(5).required(),
        expire: Joi.string().pattern(/^(\d{1,3})\s+(minute|hour|day|month|year)+$/).required()
    });

    let validate = expression.validate(request.body);
    
    if(validate.error)
    {
        return response.json({
            status: "fail",
            message: "format not valid"
        }).status(400);
    }

    const {
        data,
        domain,
        expire
    } = request.body;

    let realExpire = parseRelativeTime(expire);

    await Collection().insert({
        data: data,
        domain: domain,
        time: moment().toISOString(),
        expire: realExpire,
        catalog: catalog
    });

    return response.status(200).json({
        status: "success",
    });
}

function parseRelativeTime(relativeTime) {
    const executedReg = /^(\d+)\s+(minute|hour|day|month|year)+$/g.exec(relativeTime);

    let time = moment().add(executedReg[1], executedReg[2]);
    
    return time.toISOString();
}